@@ -246,14 +246,14 @@ def load_train_data_file(train_datafile, target, keras_options, model_options, v
         maxrows = max(10000, int(0.25*DS_LEN))
     ### first load a small sample of the dataframe and the entire target if it needs transform
     if DS_LEN > 2*maxrows:
-        print('Since number of rows > maxrows, loading a random sample of %d rows into pandas for EDA' %maxrows)
+        print('    Since number of rows > maxrows, loading a random sample of %d rows into pandas for EDA' %maxrows)
         ### we randomly sample every 2nd row until we get 10000
         skip_function = lambda x: (x != 0) and x % 5 and x < 2*maxrows
         ### load a small sample of data into a pandas dataframe ##
         train_small = pd.read_csv(train_datafile, sep=sep, skiprows=skip_function, header=header,
                         encoding=csv_encoding, nrows=maxrows, compression=compression)
     else:
-        print('Since number of rows in file <= %d maxrows, loading entire file into pandas for EDA' %maxrows)
+        print('    Since number of rows in file <= %d maxrows, loading entire file into pandas for EDA' %maxrows)
         ### load a small sample of data into a pandas dataframe ##
         train_small = pd.read_csv(train_datafile, sep=sep, nrows=maxrows, compression=compression,
                                 header=header, encoding=csv_encoding) 
@@ -264,19 +264,38 @@ def load_train_data_file(train_datafile, target, keras_options, model_options, v
     except:
         modeltype, model_label, usecols = find_problem_type(train_small, target, model_options, verbose)
     #### All column names in Tensorflow should have no spaces ! So you must convert them here!
+    sel_preds = ["_".join(x.split(" ")) for x in list(train_small) ]
+
     if header is None:
         sel_preds = ["col_"+str(x) for x in range(train_small.shape[1])]
     else:
-        sel_preds = ["_".join(x.split(" ")) for x in list(train_small) ]
+        sel_preds = ["_".join(x.split("(")) for x in sel_preds ]
+        sel_preds = ["_".join(x.split(")")) for x in sel_preds ]
+        sel_preds = ["_".join(x.split("/")) for x in sel_preds ]
+        sel_preds = ["_".join(x.split("\\")) for x in sel_preds ]
+        sel_preds = [x.lower() for x in sel_preds ]
+
     if isinstance(target, str):
         target = "_".join(target.split(" "))
+        target = "_".join(target.split("("))
+        target = "_".join(target.split(")"))
+        target = "_".join(target.split("/"))
+        target = "_".join(target.split("\\"))
+        target = target.lower()
         model_label = 'Single_Label'
     else:
         target = ["_".join(x.split(" ")) for x in target ]
+        target = ["_".join(x.split("(")) for x in target ]
+        target = ["_".join(x.split(")")) for x in target ]
+        target = ["_".join(x.split("/")) for x in target ]
+        target = ["_".join(x.split("\\")) for x in target ]
+        target = [x.lower() for x in target ]
         model_label = 'Multi_Label'
 
-    print('    Modified column names to fit no-spaces-in-column-names Rule in Tensorflow!')
     train_small.columns = sel_preds
+
+    print('Alert! Modified column names to satisfy rules for column names in Tensorflow...')
+
     ### modeltype and usecols are very important to know before doing any processing #####    
     #### usecols is a very handy tool to handle a target which can be single label or multi-label!
     if modeltype == '':
@@ -442,7 +461,7 @@ def load_train_data_file(train_datafile, target, keras_options, model_options, v
                                        compression_type=compression_type,
                                        shuffle=shuffle_flag,
                                        num_parallel_reads=tf.data.experimental.AUTOTUNE)
-        ############### Additional Checkes needed - do it here  ######
+        ############### Additional Checkes needed - do it here  #######
         if num_labels > 1:
             ############### Do this step only for Multi_Label problems ######        
             data_batches = data_batches.map(lambda x: split_combined_ds_into_two(x, usecols, preds))
@@ -451,10 +470,22 @@ def load_train_data_file(train_datafile, target, keras_options, model_options, v
             data_batches = data_batches.map(lambda x, y: to_ids(x, y, table))
             print('    target label encoding completed.')
     print('    train data loaded successfully.')
-    
+    BOOLS = cat_vocab_dict['bools']
+    #################################################################################
+    ##### F E A T U R E    E N G I N E E R I N G   H E R E              #############
+    #################################################################################
+    def process_boolean(features, target):
+        for feature_name in features:
+            if feature_name in BOOLS:
+                # Cast boolean feature values to string.
+                features[feature_name] = tf.cast(features[feature_name], tf.dtypes.float32)
+        return features, target
+    #################################################################################
+    data_batches = data_batches.map(process_boolean)    
+    print('Boolean column successfully processed')
     drop_cols = var_df1['cols_delete']
     preds = [x for x in list(train_small) if x not in usecols+drop_cols]
-    print('\nNumber of predictors to be used = %s in next step: keras preprocessing...' %len(preds))
+    print('\nNumber of predictors to be used = %s in predict step: keras preprocessing...' %len(preds))
     cat_vocab_dict['columns_deleted'] = drop_cols
     if len(drop_cols) > 0: ### drop cols that have been identified for deletion ###
         print('Dropping %s columns marked for deletion...' %drop_cols)
@@ -511,8 +542,9 @@ def fill_missing_values_for_TF2(train_small, var_df):
     ########################################################################################
     """
     train_small = copy.deepcopy(train_small)
+    bools = var_df['bools']
     cols_delete = var_df['cols_delete']
-    cat_cols = var_df['categorical_vars'] + var_df['discrete_string_vars']
+    cat_cols = var_df['categorical_vars'] + var_df['discrete_string_vars'] + bools
     int_bools = var_df['int_bools']
     int_cats = var_df['int_cats']
     ints = var_df['int_vars']
@@ -522,8 +554,8 @@ def fill_missing_values_for_TF2(train_small, var_df):
     date_vars = var_df['date_vars']
     lats = var_df['lat_vars']
     lons = var_df['lon_vars']
-    ffill_cols = lats + lons + date_vars + cols_delete
-
+    ffill_cols = lats + lons + date_vars
+    
     if len(cat_cols) > 0:
         if train_small[cat_cols].isnull().sum().sum() > 0:
             for col in cat_cols:
@@ -549,6 +581,8 @@ def fill_missing_values_for_TF2(train_small, var_df):
                 colcount = 0.0
                 train_small[col].fillna(colcount,inplace=True)
 
+    ffill_cols = train_small.columns[train_small.isnull().sum()>0]
+
     if len(ffill_cols) > 0:
         ffill_cols_copy = copy.deepcopy(ffill_cols)
         if train_small[ffill_cols].isnull().sum().sum() > 0:
@@ -569,6 +603,7 @@ def load_train_data_frame(train_small, target, keras_options, model_options, ver
     ####   first filling dataframe with pandas fillna() function!
     #############################################################################
     """
+    train_small = copy.deepcopy(train_small)
     DS_LEN = model_options['DS_LEN']
     #### do this for dataframes ##################
     try:
@@ -580,17 +615,37 @@ def load_train_data_frame(train_small, target, keras_options, model_options, ver
         batch_size = find_batch_size(DS_LEN)
     #########  Modify or Convert column names to fit tensorflow rules of no space in names!
     sel_preds = ["_".join(x.split(" ")) for x in list(train_small) ]
-    train_small.columns = sel_preds
+    #### This can also be a problem with other special characters ###    
+    sel_preds = ["_".join(x.split("(")) for x in sel_preds ]
+    sel_preds = ["_".join(x.split(")")) for x in sel_preds ]
+    sel_preds = ["_".join(x.split("/")) for x in sel_preds ]
+    sel_preds = ["_".join(x.split("\\")) for x in sel_preds ]
+    sel_preds = [x.lower() for x in sel_preds ]
+    
     if isinstance(target, str):
         target = "_".join(target.split(" "))
+        target = "_".join(target.split("("))
+        target = "_".join(target.split(")"))
+        target = "_".join(target.split("/"))
+        target = "_".join(target.split("\\"))
+        target = target.lower()
         model_label = 'Single_Label'
     else:
         target = ["_".join(x.split(" ")) for x in target ]
+        target = ["_".join(x.split("(")) for x in target ]
+        target = ["_".join(x.split(")")) for x in target ]
+        target = ["_".join(x.split("/")) for x in target ]
+        target = ["_".join(x.split("\\")) for x in target ]
+        target = [x.lower() for x in target ]
         model_label = 'Multi_Label'
-    print('    Modified file names to fit no-space in column names rule in Tensorflow!')
+
+    train_small.columns = sel_preds
+
+    print('Alert! Modified column names to satisfy rules for column names in Tensorflow...')
+
     #### if target is changed you must send that modified target back to other processes ######
     ### usecols is basically target in a list format. Very handy to know when target is a list.
-        
+    
     try:
         modeltype = model_options["modeltype"]
         if model_options["modeltype"] == '':
@@ -696,6 +751,19 @@ def load_train_data_frame(train_small, target, keras_options, model_options, ver
             ds = tf.data.Dataset.from_tensor_slices((dict(features), dict(labels)))
     else:
         ds = tf.data.Dataset.from_tensor_slices(dict(train_small))
+    #################################################################################
+    ##### F E A T U R E    E N G I N E E R I N G   H E R E              #############
+    #################################################################################
+    BOOLS = cat_vocab_dict['bools']
+    def process_boolean(features, target):
+        for feature_name in features:
+            if feature_name in BOOLS:
+                # Cast boolean feature values to string.
+                features[feature_name] = tf.cast(features[feature_name], tf.dtypes.float32)
+        return features, target
+    #################################################################################
+    ds = ds.map(process_boolean)
+    print('Boolean column successfully processed')
     ### batch it if you are creating it from a dataframe
     ds = ds.batch(batch_size, drop_remainder=True)
 
