@@ -89,13 +89,16 @@ def load_test_data(test_data_or_file, project_name, target="", cat_vocab_dict=""
     print('Loaded test data size: %d' %filesize)
     #### All column names in Tensorflow should have no spaces ! So you must convert them here!
     sel_preds = ["_".join(x.split(" ")) for x in list(test_small) ]
-    if isinstance(target, str):
-        target = "_".join(target.split(" "))
-    else:
-        target = ["_".join(x.split(" ")) for x in target ]
-    print('    Modified column names to fit no-spaces-in-column-names rule in Tensorflow!')
+    sel_preds = ["_".join(x.split("(")) for x in sel_preds ]
+    sel_preds = ["_".join(x.split(")")) for x in sel_preds ]
+    sel_preds = ["_".join(x.split("/")) for x in sel_preds ]
+    sel_preds = ["_".join(x.split("\\")) for x in sel_preds ]
+    sel_preds = [x.lower() for x in sel_preds ]
+
     test_small.columns = sel_preds
 
+    print('Alert! Modified column names to satisfy rules for column names in Tensorflow...')
+
     #### This means it is not a test dataset - hence it has target columns - load it too!
     if isinstance(target, str):
         if target == '':
@@ -105,9 +108,12 @@ def load_test_data(test_data_or_file, project_name, target="", cat_vocab_dict=""
             usecols = [target]
             target_name = copy.deepcopy(target)
     elif isinstance(target, list):
-        #### then it is a multi-label problem
-        target_name = target
-        usecols = target
+        if target == []:
+            target = ''
+        else:
+            #### then it is a multi-label problem
+            target_name = target
+            usecols = target
     else:
         print('Error: Target %s type not understood' %type(target))
         return
@@ -124,6 +130,11 @@ def load_test_data(test_data_or_file, project_name, target="", cat_vocab_dict=""
             print('Unable to load pickle file. Continuing...')
             no_cat_vocab_dict = True
     ####################################################
+    if isinstance(target, str):
+        if target == '':
+            target = cat_vocab_dict['target_variables']
+            if len(target) == 1:
+                target = target[0]
     ### classify variables using the small dataframe ##
     model_options = {}
     if no_cat_vocab_dict:
@@ -169,14 +180,15 @@ def load_test_data(test_data_or_file, project_name, target="", cat_vocab_dict=""
         if len(usecols) > 1:
             data_batches = data_batches.map(lambda x: split_combined_ds_into_two(x, usecols, preds))
     else:
+        
         if test_small.isnull().sum().sum() > 0:
             test_small = fill_missing_values_for_TF2(test_small, cat_vocab_dict)
-        
+             
         drop_cols = cat_vocab_dict['columns_deleted']
         if len(drop_cols) > 0:
             print('    Dropping %s columns from dataset...' %drop_cols)
             test_small.drop(drop_cols, axis=1, inplace=True)            
-
+        
         if isinstance(target, str):
             if target != '':
                 labels = test_small[target]
@@ -280,7 +292,18 @@ def predict(model_or_model_path, project_name, test_dataset,
         DS_LEN = 100000
         batch_size = 64
         cat_vocab_dict2 = copy.deepcopy(cat_vocab_dict)
-    ##### Now predict on the data set here ####
+    ##### Now you must convert the boolean to string on the data set here ###################
+    BOOLS = cat_vocab_dict['bools']
+    #################################################################################
+    def process_boolean(features, target):
+        for feature_name in features:
+            if feature_name in BOOLS:
+                # Cast boolean feature values to string.
+                features[feature_name] = tf.cast(features[feature_name], tf.dtypes.float32)
+        return features, target
+    ##################################################################Vaish1one1*
+    test_ds = test_ds.map(process_boolean)
+    print('Boolean column successfully processed')
     ## num_steps is needed to predict on whole dataset once ##
     try:
         num_steps = int(np.ceil(DS_LEN/batch_size))
@@ -483,4 +506,4 @@ def predict_images(test_image_dir, model_or_model_path, cat_vocab_dict):
     else:
         print('Error: test_image_dir should be either a directory containining test folder or a single JPG or PNG image file')
         return None
-########################################################################################################
\ No newline at end of file
+########################################################################################################
